;; Generated package description from org-modern.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "org-modern" "1.7" "Modern looks for Org" '((emacs "28.1") (compat "30")) :commit "e7a4c5e4a1d309895c60b3a3b3e62ab1f6a926b4" :authors '(("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("outlines" "hypermedia" "text") :url "https://github.com/minad/org-modern")
